@@ -28,7 +28,7 @@
 #define ICON_SIZE 24.0
 #define GNOME_SEARCH_TOOL_DEFAULT_ICON_SIZE 48
 #define GNOME_SEARCH_TOOL_STOCK "panel-searchtool"
-#define LEFT_LABEL_SPACING "   "
+#define LEFT_LABEL_SPACING "     "
 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
@@ -132,42 +132,24 @@ struct _PoptArgument {
 } PoptArgument;
 
 struct poptOption options[] = { 
-  	{ "name", '\0', POPT_ARG_STRING, &PoptArgument.name, 0, 
-	  N_("Set the text of 'file is named'"), NULL},
-	{ "path", '\0', POPT_ARG_STRING, &PoptArgument.path, 0, 
-	  N_("Set the text of 'look in folder'"), NULL},
-  	{ "sortby", '\0', POPT_ARG_STRING, &PoptArgument.sortby, 0, 
-	  N_("Sort files by one of the following: name, folder, size, type, or date"), NULL},
-  	{ "descending", '\0', POPT_ARG_NONE, &PoptArgument.descending, 0, 
-	  N_("Set sort order to descending, the default is ascending"), NULL},
-  	{ "start", '\0', POPT_ARG_NONE, &PoptArgument.start, 0, 
-	  N_("Automatically start a search"), NULL},
-  	{ "contains", '\0', POPT_ARG_STRING, &PoptArgument.contains, 0, 
-	  N_("Select the 'Contains the text' constraint"), NULL},
-  	{ "mtimeless", '\0', POPT_ARG_STRING, &PoptArgument.mtimeless, 0, 
-	  N_("Select the 'Date modified less than (days)' constraint"), NULL},
-  	{ "mtimemore", '\0', POPT_ARG_STRING, &PoptArgument.mtimemore, 0, 
-	  N_("Select the 'Date modified more than (days)' constraint"), NULL},
-	{ "sizeless", '\0', POPT_ARG_STRING, &PoptArgument.sizeless, 0, 
-	  N_("Select the 'Size at most (kilobytes)' constraint"), NULL},
-	{ "sizemore", '\0', POPT_ARG_STRING, &PoptArgument.sizemore, 0, 
-	  N_("Select the 'Size at least (kilobytes)' constraint"), NULL},
-	{ "empty", '\0', POPT_ARG_NONE, &PoptArgument.empty, 0, 
-	  N_("Select the 'File is empty' constraint"), NULL},
-  	{ "user", '\0', POPT_ARG_STRING, &PoptArgument.user, 0, 
-	  N_("Select the 'Owned by user' constraint"), NULL},
-  	{ "group", '\0', POPT_ARG_STRING, &PoptArgument.group, 0, 
-	  N_("Select the 'Owned by group' constraint"), NULL},
-  	{ "nouser", '\0', POPT_ARG_NONE, &PoptArgument.nouser, 0, 
-	  N_("Select the 'Owner is unrecognized' constraint"), NULL},
-  	{ "notnamed", '\0', POPT_ARG_STRING, &PoptArgument.notnamed, 0, 
-	  N_("Select the 'File is not named' constraint"), NULL},
-  	{ "regex", '\0', POPT_ARG_STRING, &PoptArgument.regex, 0, 
-	  N_("Select the 'File matches regular expression' constraint"), NULL},
-  	{ "follow", '\0', POPT_ARG_NONE, &PoptArgument.follow, 0, 
-	  N_("Select the 'Follow symbolic links' constraint"), NULL},
-  	{ "allmounts", '\0', POPT_ARG_NONE, &PoptArgument.allmounts, 0, 
-	  N_("Select the 'Include other filesystems' constraint"), NULL},
+  	{ "named", '\0', POPT_ARG_STRING, &PoptArgument.name, 0, NULL, NULL},
+	{ "path", '\0', POPT_ARG_STRING, &PoptArgument.path, 0, NULL, NULL},
+  	{ "sortby", '\0', POPT_ARG_STRING, &PoptArgument.sortby, 0, NULL, NULL},
+  	{ "descending", '\0', POPT_ARG_NONE, &PoptArgument.descending, 0, NULL, NULL},
+  	{ "start", '\0', POPT_ARG_NONE, &PoptArgument.start, 0, NULL, NULL},
+  	{ "contains", '\0', POPT_ARG_STRING, &PoptArgument.contains, 0, NULL, NULL},
+  	{ "mtimeless", '\0', POPT_ARG_STRING, &PoptArgument.mtimeless, 0, NULL, NULL},
+  	{ "mtimemore", '\0', POPT_ARG_STRING, &PoptArgument.mtimemore, 0, NULL, NULL},
+	{ "sizemore", '\0', POPT_ARG_STRING, &PoptArgument.sizemore, 0, NULL, NULL},
+	{ "sizeless", '\0', POPT_ARG_STRING, &PoptArgument.sizeless, 0, NULL, NULL},
+	{ "empty", '\0', POPT_ARG_NONE, &PoptArgument.empty, 0, NULL, NULL},
+  	{ "user", '\0', POPT_ARG_STRING, &PoptArgument.user, 0, NULL, NULL},
+  	{ "group", '\0', POPT_ARG_STRING, &PoptArgument.group, 0, NULL, NULL},
+  	{ "nouser", '\0', POPT_ARG_NONE, &PoptArgument.nouser, 0, NULL, NULL},
+  	{ "notnamed", '\0', POPT_ARG_STRING, &PoptArgument.notnamed, 0, NULL, NULL},
+  	{ "regex", '\0', POPT_ARG_STRING, &PoptArgument.regex, 0, NULL, NULL},
+  	{ "follow", '\0', POPT_ARG_NONE, &PoptArgument.follow, 0, NULL, NULL},
+  	{ "allmounts", '\0', POPT_ARG_NONE, &PoptArgument.allmounts, 0, NULL, NULL},
   	{ NULL,'\0', 0, NULL, 0, NULL, NULL}
 };
 
@@ -211,7 +193,8 @@ build_search_command (void)
 		file_is_named_escaped = escape_single_quotes (file_is_named_locale);
 		search_command.file_is_named_pattern = g_strdup(file_is_named_utf8);
 		
-		if ((locate != NULL) && (is_path_in_home_folder (look_in_folder_locale) != TRUE)) {
+		if ((locate != NULL) && (is_path_in_home_folder (look_in_folder_locale) != TRUE)
+		    && (is_path_in_mount_folder (look_in_folder_locale) != TRUE)) {
 			g_string_append_printf (command, "%s '%s*%s'", 
 						locate, 
 						look_in_folder_locale,
@@ -601,6 +584,25 @@ add_atk_relation (GtkWidget 		*obj1,
 	
 }
 
+void
+define_popt_descriptions (void) 
+{
+	gint i = 0;
+	gint j;
+
+	options[i++].descrip = g_strdup (_("Set the text of 'file is named'"));
+	options[i++].descrip = g_strdup (_("Set the text of 'look in folder'"));
+  	options[i++].descrip = g_strdup (_("Sort files by one of the following: name, folder, size, type, or date"));
+  	options[i++].descrip = g_strdup (_("Set sort order to descending, the default is ascending"));
+  	options[i++].descrip = g_strdup (_("Automatically start a search"));
+
+	for (j = 0; templates[j].type != SEARCH_CONSTRAINT_END; j++) {
+		if (templates[j].type != SEARCH_CONSTRAINT_SEPARATOR) {
+			options[i++].descrip = g_strdup_printf (_("Select the '%s' constraint"), templates[j].desc);
+		}
+	}
+}
+
 void 
 handle_popt_args (void)
 {
@@ -819,24 +821,25 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 		total_files = gtk_tree_model_iter_n_children (GTK_TREE_MODEL(interface.model), NULL);
 
 		if (total_files == 0) {
-			status_bar_string = g_strdup_printf (_("No files found %s"), 
-							     search_status);
+			status_bar_string = g_strdup (_("No files found"));
 			add_no_files_found_message (interface.model, &interface.iter);
 		}
 		else if (total_files == 1) {
-			status_bar_string = g_strdup_printf (_("One file found %s"),
-							     search_status);
+			status_bar_string = g_strdup (_("One file found"));
 		}
 		else {
-			status_bar_string = g_strdup_printf (_("%d files found %s"), total_files,
-							     search_status);
+			status_bar_string = g_strdup_printf (_("%d files found"), total_files);
 		}
+		status_bar_string = g_strconcat (status_bar_string, " ", search_status, NULL);
 
 		gnome_appbar_pop (GNOME_APPBAR (interface.status_bar));
 		gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (interface.progress_bar), 0.0);
 		gnome_appbar_push (GNOME_APPBAR (interface.status_bar), status_bar_string);
 		gtk_timeout_remove (search_data->timeout);
 
+		gtk_widget_set_sensitive (interface.additional_constraints, TRUE);
+		gtk_widget_set_sensitive (interface.disclosure, TRUE);
+		gtk_widget_set_sensitive (interface.table, TRUE);
 		gtk_widget_set_sensitive (interface.find_button, TRUE);
 		gtk_widget_hide (interface.stop_button);
 		gtk_widget_show (interface.find_button);
@@ -1015,6 +1018,9 @@ spawn_search_command (gchar *command)
 	gtk_widget_hide (interface.find_button);
 	gtk_widget_set_sensitive (interface.find_button, FALSE);
 	gtk_widget_set_sensitive (interface.results, TRUE);
+	gtk_widget_set_sensitive (interface.additional_constraints, FALSE);
+	gtk_widget_set_sensitive (interface.disclosure, FALSE);
+	gtk_widget_set_sensitive (interface.table, FALSE);
 
 	gtk_tree_view_scroll_to_point (GTK_TREE_VIEW(interface.tree), 0, 0);
 	gtk_list_store_clear (GTK_LIST_STORE(interface.model));
@@ -1210,6 +1216,7 @@ create_search_results_section (void)
 {
 	GtkWidget 	  *label;
 	GtkWidget 	  *frame;	
+	GtkWidget 	  *window;	
 	GtkTreeViewColumn *column;	
 	GtkCellRenderer   *renderer;
 	
@@ -1221,12 +1228,11 @@ create_search_results_section (void)
 	g_object_set (G_OBJECT(label), "xalign", 0.0, NULL);
 	gtk_frame_set_label_widget (GTK_FRAME(frame), label);
 	
-	interface.results = gtk_scrolled_window_new (NULL, NULL);
-	gtk_widget_set_sensitive (GTK_WIDGET(interface.results), FALSE); 
-	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW(interface.results), GTK_SHADOW_IN);	
-	gtk_container_set_border_width (GTK_CONTAINER(interface.results), 0);
-	gtk_widget_set_size_request (interface.results, 530, 200); 
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(interface.results),
+	window = gtk_scrolled_window_new (NULL, NULL); 
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW(window), GTK_SHADOW_IN);	
+	gtk_container_set_border_width (GTK_CONTAINER(window), 0);
+	gtk_widget_set_size_request (window, 530, 160); 
+	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(window),
                                         GTK_POLICY_AUTOMATIC,
                                         GTK_POLICY_AUTOMATIC);
 	
@@ -1284,8 +1290,8 @@ create_search_results_section (void)
 
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), interface.tree);
 	
-	gtk_container_add (GTK_CONTAINER(interface.results), GTK_WIDGET(interface.tree));
-	gtk_container_add (GTK_CONTAINER(frame), GTK_WIDGET(interface.results));
+	gtk_container_add (GTK_CONTAINER(window), GTK_WIDGET(interface.tree));
+	gtk_container_add (GTK_CONTAINER(frame), GTK_WIDGET(window));
 	
 	/* create the name column */
 	column = gtk_tree_view_column_new ();
@@ -1360,8 +1366,6 @@ create_main_window (void)
 	GtkWidget 	*entry;
 	GtkWidget 	*folder_entry;
 	GtkWidget 	*button;
-	GtkWidget 	*table;
-	GtkWidget 	*results;
 	GtkWidget 	*window;
 	GtkWidget	*image;
 
@@ -1374,21 +1378,21 @@ create_main_window (void)
 	image = gtk_image_new_from_stock (GNOME_SEARCH_TOOL_STOCK, gsearchtool_icon_size);
 	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, GNOME_PAD_SMALL);
 	
-	table = gtk_table_new (2, 2, FALSE);
-	gtk_table_set_row_spacings (GTK_TABLE(table), GNOME_PAD);
-	gtk_table_set_col_spacings (GTK_TABLE(table), GNOME_PAD);
-	gtk_container_add (GTK_CONTAINER(hbox), table);
+	interface.table = gtk_table_new (2, 2, FALSE);
+	gtk_table_set_row_spacings (GTK_TABLE(interface.table), GNOME_PAD);
+	gtk_table_set_col_spacings (GTK_TABLE(interface.table), GNOME_PAD);
+	gtk_container_add (GTK_CONTAINER(hbox), interface.table);
 	
 	label = gtk_label_new_with_mnemonic (_("File is _named:"));
 	gtk_label_set_justify (GTK_LABEL(label), GTK_JUSTIFY_LEFT);
 	g_object_set (G_OBJECT(label), "xalign", 0.0, NULL);
 	
-	gtk_table_attach (GTK_TABLE(table), label, 0, 1, 0, 1, GTK_FILL, 0, 0, 1);
+	gtk_table_attach (GTK_TABLE(interface.table), label, 0, 1, 0, 1, GTK_FILL, 0, 0, 1);
 
 	interface.file_is_named_entry = gnome_entry_new ("gsearchtool-file-entry");
 	gtk_label_set_mnemonic_widget (GTK_LABEL(label), gnome_entry_gtk_entry (GNOME_ENTRY(interface.file_is_named_entry)));
 	gnome_entry_set_max_saved (GNOME_ENTRY(interface.file_is_named_entry), 10);
-	gtk_table_attach (GTK_TABLE(table), interface.file_is_named_entry, 1, 2, 0, 1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+	gtk_table_attach (GTK_TABLE(interface.table), interface.file_is_named_entry, 1, 2, 0, 1, GTK_EXPAND | GTK_FILL, 0, 0, 0);
 	entry =  gnome_entry_gtk_entry (GNOME_ENTRY(interface.file_is_named_entry));
        
 	if (GTK_IS_ACCESSIBLE (gtk_widget_get_accessible(interface.file_is_named_entry)))
@@ -1411,14 +1415,14 @@ create_main_window (void)
 	gtk_label_set_justify (GTK_LABEL(label), GTK_JUSTIFY_LEFT);
 	g_object_set (G_OBJECT(label), "xalign", 0.0, NULL);
 	
-	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2, GTK_FILL, 0, 0, 0);
+	gtk_table_attach(GTK_TABLE(interface.table), label, 0, 1, 1, 2, GTK_FILL, 0, 0, 0);
 	
 	interface.look_in_folder_entry = gnome_file_entry_new ("gsearchtool-folder-entry", _("Browse"));
 	gnome_file_entry_set_directory_entry (GNOME_FILE_ENTRY(interface.look_in_folder_entry), TRUE);
 	entry = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY(interface.look_in_folder_entry));
 	gtk_label_set_mnemonic_widget (GTK_LABEL(label), entry);
 	folder_entry = gnome_file_entry_gnome_entry (GNOME_FILE_ENTRY(interface.look_in_folder_entry));
-	gtk_table_attach (GTK_TABLE(table), interface.look_in_folder_entry, 1, 2, 1, 2, GTK_EXPAND | GTK_FILL, 0, 0, 0);
+	gtk_table_attach (GTK_TABLE(interface.table), interface.look_in_folder_entry, 1, 2, 1, 2, GTK_EXPAND | GTK_FILL, 0, 0, 0);
 	
 	if (interface.is_gail_loaded)
 	{ 
@@ -1448,8 +1452,9 @@ create_main_window (void)
 
 	gtk_box_pack_start (GTK_BOX(window), GTK_WIDGET(interface.additional_constraints), FALSE, FALSE, 0);
 	
-	results = create_search_results_section ();
-	gtk_box_pack_start (GTK_BOX(window), results, TRUE, TRUE, GNOME_PAD_SMALL);
+	interface.results = create_search_results_section ();
+	gtk_widget_set_sensitive (GTK_WIDGET(interface.results), FALSE);
+	gtk_box_pack_start (GTK_BOX(window), interface.results, TRUE, TRUE, GNOME_PAD_SMALL);
 	
 	hbox = gtk_hbutton_box_new ();
 	gtk_button_box_set_layout (GTK_BUTTON_BOX(hbox), GTK_BUTTONBOX_END);
@@ -1544,6 +1549,8 @@ main (int 	argc,
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
+	define_popt_descriptions ();
+
 	gsearchtool = gnome_program_init ("gnome-search-tool", VERSION, 
 					  LIBGNOMEUI_MODULE, 
 					  argc, 
